@@ -31,7 +31,7 @@ acti <- function(x, y, dist, distarg, rhoz, p0) {
 
 #' AutoCorrelation Transformed Points
 #'
-#' Transforms a gaussian process in order to match a target marginal lowers its autocorrelation values. The actpnts evaluates the corresponding autocorrelations for the given target marginal for a set of gaussian correlations, i.e., it returns  (\eqn{\rho_x , \rho_z}) points where \eqn{\rho_x and \rho_z} represent, respectively, the autocorrelations of the target and gaussian process.
+#' Transforms a gaussian process in order to match a target marginal lowers its autocorrelation values. The actpnts evaluates the corresponding autocorrelations for the given target marginal for a set of gaussian correlations, i.e., it returns  (\eqn{\rho_x , \rho_z}) points where \eqn{\rho_x} and \eqn{\rho_z} represent, respectively, the autocorrelations of the target and gaussian process.
 #'
 #' @param margdist target marginal distribution
 #' @param margarg list of marginal distribution arguments
@@ -39,14 +39,14 @@ acti <- function(x, y, dist, distarg, rhoz, p0) {
 #' @inheritParams moments
 #'
 #' @export
-#' @import stats ggplot2
+#' @import stats ggplot2 pracma
 #'
 #' @examples
 #'
 #' library(CoSMoS)
 #'
-#' ## here we target to a process that has the Pareto type II marginal distribution
-#' ## with scale parameter 1 and shape parameter 0.3
+#' ## here we target to a process that has the Pareto type II
+#' ## marginal distribution with scale parameter 1 and shape parameter 0.3
 #' ## (note that all parameters have to be named)
 #' dist <- 'paretoII'
 #' distarg <- list(scale = 1, shape = .3)
@@ -75,9 +75,9 @@ actpnts <- function(margdist, margarg, p0 = 0, distbounds = c(-Inf, Inf)) {
                     rhox = 0) ## create data frame of marginal ACS values
 
   .min <- ifelse(test = p0 == 0,
-                 yes = -8,
+                 yes = -7.5,
                  no = -sqrt(2) * inv.erfc(2 * p0)) ## double integral lower bound
-  .max <- 8 ## double integral upper bound
+  .max <- 7.5 ## double integral upper bound
 
   m <- moments(dist = margdist, ## moment calculation
                distarg = margarg,
@@ -90,42 +90,42 @@ actpnts <- function(margdist, margarg, p0 = 0, distbounds = c(-Inf, Inf)) {
 
   for (i in 1:dim(rho)[1]) {
 
-    # temp <- integral2(acti, ## ACTI calculation using pracma
-    #                   ymin = .min,
-    #                   ymax = .max,
-    #                   xmin = .min,
-    #                   xmax = .max,
-    #                   rhoz = rho[i, 'rhoz'],
-    #                   p0 = p0,
-    #                   dist = margdist,
-    #                   distarg = margarg)$Q
+    temp <- integral2(acti, ## ACTI calculation using pracma
+                      ymin = .min,
+                      ymax = .max,
+                      xmin = .min,
+                      xmax = .max,
+                      rhoz = rho[i, 'rhoz'],
+                      p0 = p0,
+                      dist = margdist,
+                      distarg = margarg)$Q
 
-    temp <- integrate( ## ACTI using base
-      f = function(y) {
-        sapply(y, function(y) {
-          integrate(
-            f = function(x) {
-              acti(x = x,
-                   y = y,
-                   rhoz = rho[i, 'rhoz'],
-                   p0 = p0,
-                   dist = margdist,
-                   distarg = margarg)
-            },
-            lower = .min,
-            upper = .max,
-            subdivisions = 1.0e3,
-            rel.tol = 1.0e-5#,
-            # stop.on.error = FALSE
-          )$value
-        })
-      },
-      lower = .min,
-      upper = .max,
-      subdivisions = 1.0e3,
-      rel.tol = 1.0e-5#,
-      # stop.on.error = FALSE
-    )$value
+    # temp <- integrate( ## ACTI using base
+    #   f = function(y) {
+    #     sapply(y, function(y) {
+    #       integrate(
+    #         f = function(x) {
+    #           acti(x = x,
+    #                y = y,
+    #                rhoz = rho[i, 'rhoz'],
+    #                p0 = p0,
+    #                dist = margdist,
+    #                distarg = margarg)
+    #         },
+    #         lower = .min,
+    #         upper = .max,
+    #         subdivisions = 1.0e4,
+    #         rel.tol = 1.0e-5#,
+    #         # stop.on.error = FALSE
+    #       )$value
+    #     })
+    #   },
+    #   lower = .min,
+    #   upper = .max,
+    #   subdivisions = 1.0e4,
+    #   rel.tol = 1.0e-5#,
+    #   # stop.on.error = FALSE
+    # )$value
 
     rho[i, 'rhox'] <- (temp - m[[1]]['mu1'] ^ 2) / (m[[1]]['mu2'])
   }
@@ -146,7 +146,8 @@ actpnts <- function(margdist, margarg, p0 = 0, distbounds = c(-Inf, Inf)) {
 #'
 #' library(CoSMoS)
 #'
-#' ## choose the marginal distribution as Pareto type II with corresponding parameters
+#' ## choose the marginal distribution as Pareto type II
+#' ## with corresponding parameters
 #' dist <- 'paretoII'
 #' distarg <- list(scale = 1, shape = .3)
 #'
